open Common

(* TODO: do lotsa checks here *)
let f ~el ~patches ~filesdir =
    (* replace `%v' by the version. *)
    let sources_basename =
        Str.replace_first (Str.regexp "%v") el.EL.version el.EL.sources_basename
    in
    (* replace `%q' by the confopt name in confopts implemented with
       configargs. *)
    let confopts =
        let new_confopt confopt =
            match confopt.implementation with
                `configarg s ->
                    let new_s = Str.replace_first (Str.regexp "%q")
                                                  ("'${" ^ confopt.name ^ "}'")
                                                  s
                    in
                    if List.mem `configure el.EL.options then
                        { confopt with implementation = `configarg new_s }
                    else Message.die
                            ("Can't implement " ^ confopt.name ^
                             " with configure argument without a " ^
                             "configure script!")
              | `makevar s -> confopt
        in
        List.map new_confopt el.EL.confopts
    in
    (* unpacksto defaults to the basename *)
    let unpacksto = match el.EL.sources_unpacksto with
        Some u -> u
      | None -> sources_basename
    in
    (* all_target defaults to `all' *)
    let all_target = match el.EL.all_target with
        Some t -> t
      | None -> "all"
    in
    (* opt_target defaults to `opt' *)
    let opt_target = match el.EL.opt_target with
        Some t -> t
      | None -> "opt"
    in
    {
        IL.name = el.EL.name;
        IL.version = el.EL.version;
        IL.revision = el.EL.revision;
        IL.category = el.EL.category;
        IL.depends = el.EL.depends;
        IL.build_depends = el.EL.build_depends;
        IL.sources_site = el.EL.sources_site;
        IL.sources_basename = sources_basename;
        IL.sources_extension = el.EL.sources_extension;
        IL.sources_unpacksto = unpacksto;
        IL.homepage = el.EL.homepage;
        IL.maintainer = el.EL.maintainer;
        IL.short_desc = el.EL.short_desc;
        IL.long_desc = el.EL.long_desc;
        IL.options = el.EL.options;
        IL.docfiles = el.EL.docfiles;
        IL.confopts = confopts;
        IL.all_target = all_target;
        IL.opt_target = opt_target;

        IL.specfile = el.EL.specfile;
        IL.patches = patches;
        IL.filesdir = filesdir;
    }
